@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.40.2.2 2002/10/25 22:08:15 kevinv Exp $
+ $Id: battstat_applet.c,v 1.45 2002/10/25 22:12:26 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -696,6 +696,8 @@ battstat_error_dialog (PanelApplet *applet,
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_OK,
 			msg);
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (applet)));
 
 	gtk_dialog_run (GTK_DIALOG(dialog));
 	gtk_widget_destroy (dialog);
@@ -734,7 +736,7 @@ help_cb (BonoboUIComponent *uic,
 	 ProgressData      *battstat,
 	 const char        *verb)
 {
-  /* FIXME
+  /* FIXME: use (egg|gnome)_screen_help_display
    GnomeHelpMenuEntry help_entry = {
       "battstat_applet", "index.html"
    };
@@ -745,7 +747,7 @@ help_cb (BonoboUIComponent *uic,
 void
 helppref_cb (PanelApplet *applet, gpointer data)
 {
-  /* FIXME
+  /* FIXME: use (egg|gnome)_screen_help_display
        GnomeHelpMenuEntry help_entry = {
       "battstat_applet", "index.html#BATTSTAT_PREFS"
    };
@@ -849,6 +851,8 @@ about_cb (BonoboUIComponent *uic,
    	gdk_pixbuf_unref (pixbuf);
 
    gtk_window_set_wmclass (GTK_WINDOW (about_box), "battery charge monitor", "Batter Charge Monitor");
+   gtk_window_set_screen (GTK_WINDOW (about_box),
+			  gtk_widget_get_screen (battstat->applet));
    gtk_widget_show (about_box);
 }
 
