@@ -42,6 +42,7 @@
 #include <libgnomeui/libgnomeui.h>
 #include <libgnome/libgnome.h>
 #include <panel-applet-gconf.h>
+#include <egg-screen-help.h>
 #include "gkb.h"
 
 int NumLockMask, CapsLockMask, ScrollLockMask;
@@ -630,6 +631,7 @@ about_cb (BonoboUIComponent *uic,
   	g_object_unref (pixbuf);
 
   gtk_window_set_wmclass (GTK_WINDOW (about), "keyboard layout switcher", "Keyboard Layout Switcher");
+  gtk_window_set_screen (GTK_WINDOW (about), gtk_widget_get_screen (gkb->applet));
   g_signal_connect (G_OBJECT(about), "destroy",
                           (GCallback)gtk_widget_destroyed, &about);
 
@@ -644,7 +646,12 @@ help_cb (BonoboUIComponent *uic,
          const gchar	 *verbname)
 {
 	GError *error = NULL;
-        gnome_help_display("gkb",NULL,&error);
+
+	egg_screen_help_display (
+			gtk_widget_get_screen (gkb->applet),
+			"gkb", NULL, &error);
+
+	/* FIXME: display error to the user */
 }
 
 static GdkFilterReturn
