@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.48.2.2 2002/07/17 01:46:21 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.52 2002/09/19 03:15:31 mmclouglin Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -21,6 +21,7 @@
 #include <gnome.h>
 #include <panel-applet.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <egg-screen-help.h>
 
 #include "weather.h"
 #include "gweather.h"
@@ -115,9 +116,12 @@ static void help_cb (BonoboUIComponent *uic,
 		     const gchar       *verbname)
 {
     GError *error = NULL;
-    gnome_help_display("gweather",NULL,&error);
+
+    egg_screen_help_display (
+		gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
+		"gweather", NULL, &error);
  
-    if (error) {
+    if (error) { /* FIXME: the user needs to see this error */
         g_warning ("help error: %s\n", error->message);
         g_error_free (error);
         error = NULL;
