@@ -674,6 +674,8 @@ applet_about_cb (BonoboUIComponent *uic,
 	const gchar *translator_credits = _("translator_credits");
 
 	if (about) {
+		gtk_window_set_screen (GTK_WINDOW (about),
+				       gtk_widget_get_screen (GTK_WIDGET (panel_menu->applet)));
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
@@ -696,6 +698,8 @@ applet_about_cb (BonoboUIComponent *uic,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 
+	gtk_window_set_screen (GTK_WINDOW (about),
+			       gtk_widget_get_screen (GTK_WIDGET (panel_menu->applet)));
 	gtk_window_set_wmclass (GTK_WINDOW (about), "panel-menu", "PanelMenu");
 	if (pixbuf) {
 		gtk_window_set_icon (GTK_WINDOW (about), pixbuf);
